@@ -54,11 +54,6 @@ from modopt.interface.errors import warn
 from modopt.opt.cost import costObj
 from modopt.opt.linear import Identity
 
-try:
-    import cupy as cp
-except ImportError:  # pragma: no cover
-    pass
-
 
 class SetUp(Observable):
     r"""Algorithm Set-Up.
@@ -92,7 +87,7 @@ class SetUp(Observable):
         verbose=False,
         progress=True,
         step_size=None,
-        use_gpu=False,
+        compute_backend='numpy',
         **dummy_kwargs,
     ):
 
@@ -123,20 +118,9 @@ class SetUp(Observable):
             )
             self.add_observer('cv_metrics', observer)
 
-        # Check for GPU
-        if use_gpu:
-            if backend.gpu_compatibility['cupy']:
-                self.xp = cp
-            else:
-                warn(
-                    'CuPy is not installed, cannot run on GPU!'
-                    + 'Running optimization on CPU.',
-                )
-                self.xp = np
-                use_gpu = False
-        else:
-            self.xp = np
-        self.use_gpu = use_gpu
+        xp, compute_backend = backend.get_backend(compute_backend)
+        self.xp = xp
+        self.compute_backend = compute_backend
 
     @property
     def metrics(self):
@@ -148,7 +132,9 @@ class SetUp(Observable):
 
         if isinstance(metrics, type(None)):
             self._metrics = {}
-        elif not isinstance(metrics, dict):
+        elif isinstance(metrics, dict):
+            self._metrics = metrics
+        else:
             raise TypeError(
                 'Metrics must be a dictionary, not {0}.'.format(type(metrics)),
             )
@@ -184,10 +170,10 @@ class SetUp(Observable):
             Copy of input data
 
         """
-        if self.use_gpu:
-            return backend.move_to_device(input_data)
-
-        return self.xp.copy(input_data)
+        return self.xp.copy(backend.change_backend(
+            input_data,
+            self.compute_backend,
+        ))
 
     def _check_input_data(self, input_data):
         """Check input data type.
@@ -205,8 +191,10 @@ class SetUp(Observable):
             For invalid input type
 
         """
-        if not isinstance(input_data, self.xp.ndarray):
-            raise TypeError('Input data must be a numpy array.')
+        if not (isinstance(input_data, (self.xp.ndarray, np.ndarray))):
+            raise TypeError(
+                'Input data must be a numpy array or backend array',
+            )
 
     def _check_param(self, param_val):
         """Check algorithm parameters.
@@ -779,8 +767,8 @@ class ForwardBackward(SetUp):
             self._z_new = self._x_new
 
         # Update old values for next iteration.
-        self.xp.copyto(self._x_old, self._x_new)
-        self.xp.copyto(self._z_old, self._z_new)
+        self._x_old = self.xp.copy(self._x_new)
+        self._z_old = self.xp.copy(self._z_new)
 
         # Update parameter values for next iteration.
         self._update_param()
@@ -789,7 +777,7 @@ class ForwardBackward(SetUp):
         if self._cost_func:
             self.converge = (
                 self.any_convergence_flag()
-                or self._cost_func.get_cost(self._x_new),
+                or self._cost_func.get_cost(self._x_new)
             )
 
     def iterate(self, max_iter=150):
@@ -1548,7 +1536,7 @@ class POGM(SetUp):
         if self._cost_func:
             self.converge = (
                 self.any_convergence_flag()
-                or self._cost_func.get_cost(self._x_new),
+                or self._cost_func.get_cost(self._x_new)
             )
 
     def iterate(self, max_iter=150):
